@@ -2,7 +2,8 @@ read_lcm_raw <- function(fname, ft, fs, ref, extra) {
   in_nmid <- FALSE 
   con <- file(fname, "rb")
   while (length(line <- readLines(con, n = 1, warn = FALSE)) > 0) {
-    if (endsWith(line, "$NMID")) {
+    # if (endsWith(line, "$NMID") | startsWith(line, " $NMID")) {
+    if (grepl("$NMID", line, fixed = TRUE)) {
       in_nmid <- TRUE
     } else if (endsWith(line, "$END") && in_nmid) {
       
@@ -25,7 +26,7 @@ read_lcm_raw <- function(fname, ft, fs, ref, extra) {
   close(con)
 
   data <- as.vector(t(as.matrix(x)))
-  N <- length(data)/2
+  N <- length(data) / 2
   data <- data[seq(1, 2 * N, 2)] +
           1i * data[seq(2, 2 * N, 2)]
   
